/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.common.zufi;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.ArgumentCaptor;
import org.mockito.Captor;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.eingang.common.zufi.OrganisationsEinheit;
import de.ozgcloud.eingang.common.zufi.OrganisationsEinheitMapper;
import de.ozgcloud.eingang.common.zufi.OrganisationsEinheitRemoteService;
import de.ozgcloud.zufi.grpc.organisationseinheit.GrpcOrganisationsEinheitGetRequest;
import de.ozgcloud.zufi.grpc.organisationseinheit.GrpcOrganisationsEinheitGetResponse;
import de.ozgcloud.zufi.grpc.organisationseinheit.OrganisationsEinheitServiceGrpc.OrganisationsEinheitServiceBlockingStub;

class OrganisationsEinheitRemoteServiceTest {

	@InjectMocks
	private OrganisationsEinheitRemoteService service;
	@Mock
	private OrganisationsEinheitServiceBlockingStub stub;
	@Mock
	private OrganisationsEinheitMapper mapper;

	@DisplayName("Get by id")
	@Nested
	class TestGetById {

		private final GrpcOrganisationsEinheitGetResponse response = GrpcOrganisationsEinheitGetResponseTestFactory.create();
		private final OrganisationsEinheit mappedOrganisationsEinheit = OrganisationsEinheitTestFactory.create();

		@BeforeEach
		void mock() {
			when(stub.getById(any())).thenReturn(response);
			when(mapper.fromGrpc(any())).thenReturn(mappedOrganisationsEinheit);
		}

		@Captor
		private ArgumentCaptor<GrpcOrganisationsEinheitGetRequest> requestCaptor;

		@Test
		void shouldCallRemoteService() {
			service.getById(OrganisationsEinheitTestFactory.ID);

			verify(stub).getById(requestCaptor.capture());
			assertThat(requestCaptor.getValue().getId()).isEqualTo(OrganisationsEinheitTestFactory.ID);
		}

		@Test
		void shouldCallMapper() {
			service.getById(OrganisationsEinheitTestFactory.ID);

			verify(mapper).fromGrpc(response.getOrganisationsEinheit());
		}

		@Test
		void shouldReturnValue() {
			var organisationsEinheit = service.getById(OrganisationsEinheitTestFactory.ID);

			assertThat(organisationsEinheit).isEqualTo(mappedOrganisationsEinheit);
		}
	}
}
