/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.xta;

import static org.assertj.core.api.Assertions.*;

import jakarta.validation.Valid;

import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.ActiveProfiles;

import de.ozgcloud.eingang.Application;

@Disabled("real live test - do only activate for manual testing")
@ActiveProfiles({ "itcase", "local" })
@SpringBootTest(classes = Application.class, //
		properties = { "ozgcloud.xta.server.name=LI33-0005",
				"ozgcloud.xta.server.address=LI33-0005:3000",
				"ozgcloud.xta.server.protocol=https",
				"ozgcloud.xta.keystore.file=file:./KOP_SH_KIEL_DEV.p12",
				"ozgcloud.xta.keystore.password=geheim" // replace this with real password
		})
class XtaRemoteServiceITCase {

	@Autowired
	private XtaRemoteService remoteService;
	@Autowired
	@Valid
	private XtaProperties xtaProperties;

	@Nested
	class TestProperties {
		@Test
		void shouldHaveStatusListAction() {
			assertThat(xtaProperties.getActions().getStatusList()).isNotNull();
		}
	}

	@Nested
	class TestGetStatusList {

		@Test
		void shouldSendRequest() {

			var result = remoteService.getStatusList();

			assertThat(result).isNotNull();

		}
	}

	@Nested
	class TestGetMessage {
		@Test
		void shouldSendRequest() {
			var result = remoteService.loadContentContainer("urn:de:xta:messageid:dataport_xta_210:20eb297a-e224-45a0-9376-5ebd4d9bcc9a");

			assertThat(result).isNotNull();
		}
	}

	@Nested
	class TestClose {
		@Test
		void shouldThrowNoException() {
			assertThatNoException().isThrownBy(() -> remoteService.close(XtaMessageTestFactory.MESSAGE_ID));
		}
	}
}
